// Copyright (c) 2012, Ladislav Thon. All rights reserved. Use of this source
// code is governed by a BSD-style license that can be found in the LICENSE file.

import 'dart:io';
import 'package:darmatch/matchers.dart';
import 'package:darmatch/io_matchers.dart';

import 'package:detester/detester.dart';
part 'package:detester/test.dart';

suite() => configure("IO matchers",
  [
    testFileExists,
    testFileLength,
    testFileContent,
    testDirectoryExists
  ],
  beforeSuite: initScript
);

var script;

initScript() {
  script = new Options().script;
}

testFileExists() {
  expectThat(new File(script), fileExists());
  expectThat(new File("${script}xxx"), not(fileExists()));
}

testFileLength() {
  expectThat(new File(script), fileLength(greaterThan(0)));
  expectThat(new File(script), fileLength(equals(1474)));
  expectThat(new File(script), fileLength(lessThan(8192)));
  expectThat(new File("${script}xxx"), not(fileLength(greaterThan(0))));
}

testFileContent() {
  expectThat(new File(script), fileContent(beginsWith("// Copyright (c) 2012, Ladislav Thon")));
  expectThat(new File(script), not(fileContent(beginsWith("Copyright (c) 2012, Ladislav Thon"))));
  expectThat(new File("${script}xxx"), not(fileContent(beginsWith("Copyright (c) 2012, Ladislav Thon"))));
}

testDirectoryExists() {
  var dir = new File(script).directorySync();
  expectThat(dir, directoryExists());
  expectThat(new Directory("${dir.path}xxx"), not(directoryExists()));
}

